// Includes all header files for agtboost
// Berent Lunde
// 25.07.2019


#ifndef __GMGTB_HPP_INCLUDED__
#define __GMGTB_HPP_INCLUDED__

// External
#include "external_rcpp.hpp"

#include <iostream>
#include <fstream>
#include <functional>

// Internal
#include "cir.hpp"
#include "gumbel.hpp"
#include "node.hpp"
#include "tree.hpp"
#include "ensemble.hpp"
#include "optimization.hpp"
#include "loss_functions.hpp"
#include "gbt_count_auto.hpp"
#include "initial_prediction.hpp"


#endif // __GMGTB_HPP_INCLUDED__
